#!/bin/sh

# This file is used by spequlos to remotely starts the cloud worker and make it join the DG
# This script takes 2 arguments :
# - The first argument is the batch_id associated to the worker. For XWHEP it is not used.
# - The second argument is some batch specific information. For XWHEP it is the group UID associated to the batch_id and it is the only information used to retrieve the batch


XWHEP_DIR=/opt/xwhep-worker-7.3.2.xw.lri.fr/

if [ ! -d $XWHEP_DIR ]
then
    echo "Error: Unable to find the directory containing XWHEP at $XWHEP_DIR"
    exit 1
fi

cp -a $XWHEP_DIR /opt/xwhep-worker

BIN_FILE=/opt/xwhep-worker/bin/xtremweb.worker
CONF_FILE=/opt/xwhep-worker/conf/xtremweb.worker.conf

if [ ! -f $BIN_FILE ]
then
    echo "Error: Unable to find the executable at $BIN_FILE"
    exit 1
fi

if [ ! -f $CONF_FILE ]
then
    echo "Error: Unable to find the configuration file at $CONF_FILE"
    exit 1
fi


echo "Starting cloudworker for XWHEP@xw.lri.fr"
echo "Argument supplied : $*"

if [ $# -ge 2 ]
then
    batchid=$2
    echo "Using $batchid as batchid URI to compute"
    echo "Tuning configuration file..."
    grep -v ^batchid $CONF_FILE > /tmp/tmp_conf_file
    mv /tmp/tmp_conf_file $CONF_FILE
    echo "batchid=$batchid" >> $CONF_FILE
else
    echo "No specific batchid to compute"
    echo "Tuning configuration file..."
    grep -v ^batchid $CONF_FILE > /tmp/tmp_conf_file
    mv /tmp/tmp_conf_file $CONF_FILE
fi

$BIN_FILE console > /tmp/XW-log-`date +'%F-%s'` 2>  /tmp/XW-err-`date +'%F-%s'` &

exit $?
