#! /usr/bin/python

"""Unit tests for deposit.py

"""
import sys
import os
sys.path.append(os.path.join(sys.path[0],".."))
sys.path.append(os.path.join(sys.path[0],"..",".."))
os.chdir(os.path.join(sys.path[0],".."))

from tools import db_func
from deposit import deposit
import unittest
import random

class BadArgument(unittest.TestCase):
    """Test for bad arguments

    
    """
    
    def testUnknownDGId(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        dg_id = random.randint(1000,10000)        
        self.assertEqual(deposit(conn,dg_id,0,1), None)
        db_func.disconnect(conn)

    def testNonIntDGId(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        dg_id = str(0)
        self.assertEqual(deposit(conn,dg_id,0,1), None)
        db_func.disconnect(conn)
    
    def testUnknownInstitutionId(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        i_id = random.randint(1000,10000)        
        self.assertEqual(deposit(conn,0,i_id,1), None)
        db_func.disconnect(conn)

    def testNonIntInstitutionId(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        i_id = str(0)
        self.assertEqual(deposit(conn,0,i_id,1), None)
        db_func.disconnect(conn)

    def testWrongDBConn(self):
        conn=db_func.connect(db_func.read_db_config("../scheduler/db.cfg"))
        self.assertEqual(deposit(conn,0,0,1), None)
        db_func.disconnect(conn)

    def testNoDBConn(self):
        self.assertEqual(deposit(None,0,0,1), None)

    def testNegativeCredit(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        credit = -random.randint(0,1000)
        self.assertEqual(deposit(conn,0,0,credit), None)
        db_func.disconnect(conn)
    
    def testZeroCredit(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        credit = 0
        self.assertEqual(deposit(conn,0,0,credit), None)
        db_func.disconnect(conn)
                
    def testNonIntCredit(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        credit = str(random.randint(0,1000))
        self.assertEqual(deposit(conn,0,0,credit), None)
        db_func.disconnect(conn)
        

class BadReturn(unittest.TestCase):
    """Test for bad returned values
    
    """
    
    def testReturnAreBoolOrNone(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))    
        res = deposit(conn,0,0,1)
        self.assert_(res==None or isinstance(res, bool))
        db_func.disconnect(conn)


class ConsistencyCheck(unittest.TestCase):
    """Test consistency
    
    """

    def testDepositShouldEnd(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))        
        for i in range(0,1000):
            if not deposit(conn,0,0,5):
                break
        self.assert_(i<999)
        db_func.disconnect(conn)   
    
    
            
if __name__ == "__main__":
    unittest.main()   
