#! /usr/bin/python

"""Unit tests for get_credits.py

"""
import sys
import os
sys.path.append(os.path.join(sys.path[0],".."))
sys.path.append(os.path.join(sys.path[0],"..",".."))
os.chdir(os.path.join(sys.path[0],".."))

from tools import db_func
from get_credits import get_credits
import unittest
import random

DEFAULT_BATCH_ID="batch_0"

class BadArgument(unittest.TestCase):
    """Test for bad arguments

    
    """
    
    def testUnknownBatchId(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        batch_id = str(-random.randint(1000,10000))
        self.assertEqual(get_credits(conn,batch_id), 0)
        db_func.disconnect(conn)

    def testNonStrBatchId(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        batch_id = random.randint(0,1000)
        self.assertEqual(get_credits(conn,batch_id), None)
        db_func.disconnect(conn)
    
    def testWrongDBConn(self):
        conn=db_func.connect(db_func.read_db_config("../scheduler/db.cfg"))
        self.assertEqual(get_credits(conn,DEFAULT_BATCH_ID), None)
        db_func.disconnect(conn)

    def testNoDBConn(self):
        self.assertEqual(get_credits(None,DEFAULT_BATCH_ID), None)


class BadReturn(unittest.TestCase):
    """Test for bad returned values
    
    """
    
    def testReturnIsPositiveInt(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))    
        res = get_credits(conn,DEFAULT_BATCH_ID)
        self.assert_(isinstance(res, int) and res>=0)
        db_func.disconnect(conn)


class ConsistencyCheck(unittest.TestCase):
    """Test consistency
    
    """

    def testGetCreditsIsConstant(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))        
        res = get_credits(conn,DEFAULT_BATCH_ID)
        for i in range(0,10):
            self.assert_(get_credits(conn,DEFAULT_BATCH_ID)==res)
        db_func.disconnect(conn)   
    
    
            
if __name__ == "__main__":
    unittest.main()   
