#! /usr/bin/python

"""Unit tests for pay.py

"""
import sys
import os
sys.path.append(os.path.join(sys.path[0],".."))
sys.path.append(os.path.join(sys.path[0],"..",".."))
os.chdir(os.path.join(sys.path[0],".."))

from tools import db_func
from pay import pay
import unittest
import random

DEFAULT_BATCH_ID="batch_0"

class BadArgument(unittest.TestCase):
    """Test for bad arguments

    
    """
    
    def testUnknownBatchId(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        batch_id = str(-random.randint(1000,10000))
        self.assertEqual(pay(conn,batch_id), None)
        db_func.disconnect(conn)

    def testNonStrBatchId(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))
        batch_id = random.randint(0,1000)
        self.assertEqual(pay(conn,batch_id), None)
        db_func.disconnect(conn)
    
    def testWrongDBConn(self):
        conn=db_func.connect(db_func.read_db_config("../scheduler/db.cfg"))
        self.assertEqual(pay(conn,DEFAULT_BATCH_ID), None)
        db_func.disconnect(conn)

    def testNoDBConn(self):
        self.assertEqual(pay(None,DEFAULT_BATCH_ID), None)


class BadReturn(unittest.TestCase):
    """Test for bad returned values
    
    """
    
    def testReturnIsNoneOrBool(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))    
        res = pay(conn,DEFAULT_BATCH_ID)
        self.assert_(res==None or isinstance(res, bool) )
        db_func.disconnect(conn)


class ConsistencyCheck(unittest.TestCase):
    """Test consistency
    
    """

    def testPayOnlyOneTime(self):
        conn=db_func.connect(db_func.read_db_config("db.cfg"))        
        if pay(conn,DEFAULT_BATCH_ID):
            self.assert_(pay(conn,DEFAULT_BATCH_ID)==None)
        db_func.disconnect(conn)   
    
    
            
if __name__ == "__main__":
    unittest.main()   
