#! /usr/bin/python

"""Unit tests for get_n_jobs.py

"""
import sys
import os
sys.path.append(os.path.join(sys.path[0],".."))
sys.path.append(os.path.join(sys.path[0],"..",".."))
os.chdir(os.path.join(sys.path[0],".."))

from tools import db_func
from get_n_jobs import get_n_jobs
import unittest
import random
import datetime
import time 

DEFAULT_BATCH_ID = "batch_0"

class BadArgument(unittest.TestCase):
    """Test for bad arguments

    
    """
    
    def testUnknownBatchId(self):
        conn=db_func.connect(db_func.read_db_config("info_db.cfg"))
        batch_id = str(random.randint(0,1000))        
        self.assertEqual(get_n_jobs(conn,batch_id), None)
        db_func.disconnect(conn)

    def testNonStrBatchId(self):
        conn=db_func.connect(db_func.read_db_config("info_db.cfg"))
        batch_id = random.randint(0,1000)
        self.assertEqual(get_n_jobs(conn,batch_id), None)
        db_func.disconnect(conn)

    def testWrongDBConn(self):
        conn=db_func.connect(db_func.read_db_config("../scheduler/db.cfg"))
        self.assertEqual(get_n_jobs(conn,DEFAULT_BATCH_ID), None)
        db_func.disconnect(conn)

    def testNoDBConn(self):
        self.assertEqual(get_n_jobs(None,DEFAULT_BATCH_ID), None)


class BadReturn(unittest.TestCase):
    """Test for bad returned values
    
    """
    
    def testReturnArePositiveIntType(self):
        conn=db_func.connect(db_func.read_db_config("info_db.cfg"))    
        self.assert_(isinstance(get_n_jobs(conn,DEFAULT_BATCH_ID), int))        
        self.assert_(get_n_jobs(conn,DEFAULT_BATCH_ID)>0)        
        db_func.disconnect(conn)


class ConsistencyCheck(unittest.TestCase):
    """Test consistency
    
    """
    
    
    
    
            
if __name__ == "__main__":
    unittest.main()   
