#!/usr/bin/python

"""//Module for web service operation//
 
- > This module contains function to call and get results from a distant web page, generated by python CGI and publishing its results using the cgi_func module

- File: web_func.py

"""

import log_func
log=log_func.get_spequlos_log(__file__)


import urllib                                       
from sgmllib import SGMLParser


class SpequlosWebParser(SGMLParser):
    """HTML parser to grab information enclosed in specific HTML tag. It overrides the SGMLParser to recognize text published inside the tags:
    ```
    <div class="qos">TEXT</div>
    ```
    Each text parsed this way is added to the parser attribute results as a list of string
    
    """
    def __init__(self):
        SGMLParser.__init__(self)
        self.is_result=False
        self.results=[]

    def reset(self):                           
        SGMLParser.reset(self)
        self.results = []
    
    def start_div(self,attrs):
        #for each attribute inside a <div ...> tag, 
        #   if the attribute is class="qos", 
        #        be prepared to read result
        for key,value in attrs:
            if key=="class" and value=="qos":
                self.is_result=True

    def end_div(self):
        #if we have a </div> tag, we don't need to be prepared to read a result anymore
        self.is_result=False

    def handle_data(self, text):
        #if we are prepared to read result
        #   append the result read to the results list
        if self.is_result:
            self.results.append(text)


def call(url):
    """Calls a distant function generated by python CGI and get its results.     

    - Arguments:
     - url --- The URL of the distant function
         
    - The function returns, as a list of strings, the results published on called web page and enclosed in ``<div class="qos">...</div>`` tags

    """
    try:
        sock = urllib.urlopen(url) 
    except Exception as e:
        log.error("Error when openning the url %s" % url)
        log.error(e)
        return None
    parser = SpequlosWebParser()    
    parser.feed(sock.read())
    sock.close()                                       
    parser.close()
    return parser.results

if __name__=="__main__":
    import sys
    print call(sys.argv[1])
